import * as bingo_stratum from 'bingo-stratum';
import * as zod from 'zod';
export { presetCommon } from './common.js';
export { presetEverything } from './everything.js';
export { presetMinimal } from './minimal.js';

declare const presets: {
    common: bingo_stratum.Preset<{
        access: zod.ZodUnion<[zod.ZodLiteral<"public">, zod.ZodLiteral<"restricted">]>;
        author: zod.ZodOptional<zod.ZodString>;
        bin: zod.ZodOptional<zod.ZodUnion<[zod.ZodString, zod.ZodRecord<zod.ZodString, zod.ZodString>]>>;
        contributors: zod.ZodOptional<zod.ZodArray<zod.ZodObject<{
            avatar_url: zod.ZodString;
            contributions: zod.ZodArray<zod.ZodString, "many">;
            login: zod.ZodString;
            name: zod.ZodString;
            profile: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            avatar_url: string;
            contributions: string[];
            login: string;
            name: string;
            profile: string;
        }, {
            avatar_url: string;
            contributions: string[];
            login: string;
            name: string;
            profile: string;
        }>, "many">>;
        description: zod.ZodDefault<zod.ZodString>;
        directory: zod.ZodString;
        documentation: zod.ZodOptional<zod.ZodString>;
        email: zod.ZodEffects<zod.ZodUnion<[zod.ZodString, zod.ZodObject<{
            github: zod.ZodString;
            npm: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            github: string;
            npm: string;
        }, {
            github: string;
            npm: string;
        }>]>, {
            github: string;
            npm: string;
        }, string | {
            github: string;
            npm: string;
        }>;
        emoji: zod.ZodOptional<zod.ZodString>;
        existingLabels: zod.ZodOptional<zod.ZodArray<zod.ZodObject<{
            color: zod.ZodString;
            description: zod.ZodString;
            name: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            name: string;
            description: string;
            color: string;
        }, {
            name: string;
            description: string;
            color: string;
        }>, "many">>;
        explainer: zod.ZodOptional<zod.ZodArray<zod.ZodString, "many">>;
        funding: zod.ZodOptional<zod.ZodString>;
        guide: zod.ZodOptional<zod.ZodObject<{
            href: zod.ZodString;
            title: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            href: string;
            title: string;
        }, {
            href: string;
            title: string;
        }>>;
        keywords: zod.ZodOptional<zod.ZodArray<zod.ZodString, "many">>;
        logo: zod.ZodOptional<zod.ZodObject<{
            alt: zod.ZodString;
            height: zod.ZodOptional<zod.ZodNumber>;
            src: zod.ZodString;
            width: zod.ZodOptional<zod.ZodNumber>;
        }, "strip", zod.ZodTypeAny, {
            alt: string;
            src: string;
            height?: number | undefined;
            width?: number | undefined;
        }, {
            alt: string;
            src: string;
            height?: number | undefined;
            width?: number | undefined;
        }>>;
        node: zod.ZodOptional<zod.ZodObject<{
            minimum: zod.ZodString;
            pinned: zod.ZodOptional<zod.ZodString>;
        }, "strip", zod.ZodTypeAny, {
            minimum: string;
            pinned?: string | undefined;
        }, {
            minimum: string;
            pinned?: string | undefined;
        }>>;
        owner: zod.ZodString;
        packageData: zod.ZodOptional<zod.ZodObject<{
            dependencies: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
            devDependencies: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
            scripts: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
        }, "strip", zod.ZodTypeAny, {
            dependencies?: Record<string, string> | undefined;
            devDependencies?: Record<string, string> | undefined;
            scripts?: Record<string, string> | undefined;
        }, {
            dependencies?: Record<string, string> | undefined;
            devDependencies?: Record<string, string> | undefined;
            scripts?: Record<string, string> | undefined;
        }>>;
        pnpm: zod.ZodOptional<zod.ZodString>;
        repository: zod.ZodString;
        rulesetId: zod.ZodOptional<zod.ZodString>;
        title: zod.ZodString;
        usage: zod.ZodOptional<zod.ZodString>;
        version: zod.ZodOptional<zod.ZodString>;
        words: zod.ZodOptional<zod.ZodArray<zod.ZodString, "many">>;
        workflowsVersions: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodRecord<zod.ZodString, zod.ZodObject<{
            hash: zod.ZodOptional<zod.ZodString>;
            pinned: zod.ZodOptional<zod.ZodBoolean>;
        }, "strip", zod.ZodTypeAny, {
            pinned?: boolean | undefined;
            hash?: string | undefined;
        }, {
            pinned?: boolean | undefined;
            hash?: string | undefined;
        }>>>>;
    }>;
    everything: bingo_stratum.Preset<{
        access: zod.ZodUnion<[zod.ZodLiteral<"public">, zod.ZodLiteral<"restricted">]>;
        author: zod.ZodOptional<zod.ZodString>;
        bin: zod.ZodOptional<zod.ZodUnion<[zod.ZodString, zod.ZodRecord<zod.ZodString, zod.ZodString>]>>;
        contributors: zod.ZodOptional<zod.ZodArray<zod.ZodObject<{
            avatar_url: zod.ZodString;
            contributions: zod.ZodArray<zod.ZodString, "many">;
            login: zod.ZodString;
            name: zod.ZodString;
            profile: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            avatar_url: string;
            contributions: string[];
            login: string;
            name: string;
            profile: string;
        }, {
            avatar_url: string;
            contributions: string[];
            login: string;
            name: string;
            profile: string;
        }>, "many">>;
        description: zod.ZodDefault<zod.ZodString>;
        directory: zod.ZodString;
        documentation: zod.ZodOptional<zod.ZodString>;
        email: zod.ZodEffects<zod.ZodUnion<[zod.ZodString, zod.ZodObject<{
            github: zod.ZodString;
            npm: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            github: string;
            npm: string;
        }, {
            github: string;
            npm: string;
        }>]>, {
            github: string;
            npm: string;
        }, string | {
            github: string;
            npm: string;
        }>;
        emoji: zod.ZodOptional<zod.ZodString>;
        existingLabels: zod.ZodOptional<zod.ZodArray<zod.ZodObject<{
            color: zod.ZodString;
            description: zod.ZodString;
            name: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            name: string;
            description: string;
            color: string;
        }, {
            name: string;
            description: string;
            color: string;
        }>, "many">>;
        explainer: zod.ZodOptional<zod.ZodArray<zod.ZodString, "many">>;
        funding: zod.ZodOptional<zod.ZodString>;
        guide: zod.ZodOptional<zod.ZodObject<{
            href: zod.ZodString;
            title: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            href: string;
            title: string;
        }, {
            href: string;
            title: string;
        }>>;
        keywords: zod.ZodOptional<zod.ZodArray<zod.ZodString, "many">>;
        logo: zod.ZodOptional<zod.ZodObject<{
            alt: zod.ZodString;
            height: zod.ZodOptional<zod.ZodNumber>;
            src: zod.ZodString;
            width: zod.ZodOptional<zod.ZodNumber>;
        }, "strip", zod.ZodTypeAny, {
            alt: string;
            src: string;
            height?: number | undefined;
            width?: number | undefined;
        }, {
            alt: string;
            src: string;
            height?: number | undefined;
            width?: number | undefined;
        }>>;
        node: zod.ZodOptional<zod.ZodObject<{
            minimum: zod.ZodString;
            pinned: zod.ZodOptional<zod.ZodString>;
        }, "strip", zod.ZodTypeAny, {
            minimum: string;
            pinned?: string | undefined;
        }, {
            minimum: string;
            pinned?: string | undefined;
        }>>;
        owner: zod.ZodString;
        packageData: zod.ZodOptional<zod.ZodObject<{
            dependencies: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
            devDependencies: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
            scripts: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
        }, "strip", zod.ZodTypeAny, {
            dependencies?: Record<string, string> | undefined;
            devDependencies?: Record<string, string> | undefined;
            scripts?: Record<string, string> | undefined;
        }, {
            dependencies?: Record<string, string> | undefined;
            devDependencies?: Record<string, string> | undefined;
            scripts?: Record<string, string> | undefined;
        }>>;
        pnpm: zod.ZodOptional<zod.ZodString>;
        repository: zod.ZodString;
        rulesetId: zod.ZodOptional<zod.ZodString>;
        title: zod.ZodString;
        usage: zod.ZodOptional<zod.ZodString>;
        version: zod.ZodOptional<zod.ZodString>;
        words: zod.ZodOptional<zod.ZodArray<zod.ZodString, "many">>;
        workflowsVersions: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodRecord<zod.ZodString, zod.ZodObject<{
            hash: zod.ZodOptional<zod.ZodString>;
            pinned: zod.ZodOptional<zod.ZodBoolean>;
        }, "strip", zod.ZodTypeAny, {
            pinned?: boolean | undefined;
            hash?: string | undefined;
        }, {
            pinned?: boolean | undefined;
            hash?: string | undefined;
        }>>>>;
    }>;
    minimal: bingo_stratum.Preset<{
        access: zod.ZodUnion<[zod.ZodLiteral<"public">, zod.ZodLiteral<"restricted">]>;
        author: zod.ZodOptional<zod.ZodString>;
        bin: zod.ZodOptional<zod.ZodUnion<[zod.ZodString, zod.ZodRecord<zod.ZodString, zod.ZodString>]>>;
        contributors: zod.ZodOptional<zod.ZodArray<zod.ZodObject<{
            avatar_url: zod.ZodString;
            contributions: zod.ZodArray<zod.ZodString, "many">;
            login: zod.ZodString;
            name: zod.ZodString;
            profile: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            avatar_url: string;
            contributions: string[];
            login: string;
            name: string;
            profile: string;
        }, {
            avatar_url: string;
            contributions: string[];
            login: string;
            name: string;
            profile: string;
        }>, "many">>;
        description: zod.ZodDefault<zod.ZodString>;
        directory: zod.ZodString;
        documentation: zod.ZodOptional<zod.ZodString>;
        email: zod.ZodEffects<zod.ZodUnion<[zod.ZodString, zod.ZodObject<{
            github: zod.ZodString;
            npm: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            github: string;
            npm: string;
        }, {
            github: string;
            npm: string;
        }>]>, {
            github: string;
            npm: string;
        }, string | {
            github: string;
            npm: string;
        }>;
        emoji: zod.ZodOptional<zod.ZodString>;
        existingLabels: zod.ZodOptional<zod.ZodArray<zod.ZodObject<{
            color: zod.ZodString;
            description: zod.ZodString;
            name: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            name: string;
            description: string;
            color: string;
        }, {
            name: string;
            description: string;
            color: string;
        }>, "many">>;
        explainer: zod.ZodOptional<zod.ZodArray<zod.ZodString, "many">>;
        funding: zod.ZodOptional<zod.ZodString>;
        guide: zod.ZodOptional<zod.ZodObject<{
            href: zod.ZodString;
            title: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            href: string;
            title: string;
        }, {
            href: string;
            title: string;
        }>>;
        keywords: zod.ZodOptional<zod.ZodArray<zod.ZodString, "many">>;
        logo: zod.ZodOptional<zod.ZodObject<{
            alt: zod.ZodString;
            height: zod.ZodOptional<zod.ZodNumber>;
            src: zod.ZodString;
            width: zod.ZodOptional<zod.ZodNumber>;
        }, "strip", zod.ZodTypeAny, {
            alt: string;
            src: string;
            height?: number | undefined;
            width?: number | undefined;
        }, {
            alt: string;
            src: string;
            height?: number | undefined;
            width?: number | undefined;
        }>>;
        node: zod.ZodOptional<zod.ZodObject<{
            minimum: zod.ZodString;
            pinned: zod.ZodOptional<zod.ZodString>;
        }, "strip", zod.ZodTypeAny, {
            minimum: string;
            pinned?: string | undefined;
        }, {
            minimum: string;
            pinned?: string | undefined;
        }>>;
        owner: zod.ZodString;
        packageData: zod.ZodOptional<zod.ZodObject<{
            dependencies: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
            devDependencies: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
            scripts: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
        }, "strip", zod.ZodTypeAny, {
            dependencies?: Record<string, string> | undefined;
            devDependencies?: Record<string, string> | undefined;
            scripts?: Record<string, string> | undefined;
        }, {
            dependencies?: Record<string, string> | undefined;
            devDependencies?: Record<string, string> | undefined;
            scripts?: Record<string, string> | undefined;
        }>>;
        pnpm: zod.ZodOptional<zod.ZodString>;
        repository: zod.ZodString;
        rulesetId: zod.ZodOptional<zod.ZodString>;
        title: zod.ZodString;
        usage: zod.ZodOptional<zod.ZodString>;
        version: zod.ZodOptional<zod.ZodString>;
        words: zod.ZodOptional<zod.ZodArray<zod.ZodString, "many">>;
        workflowsVersions: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodRecord<zod.ZodString, zod.ZodObject<{
            hash: zod.ZodOptional<zod.ZodString>;
            pinned: zod.ZodOptional<zod.ZodBoolean>;
        }, "strip", zod.ZodTypeAny, {
            pinned?: boolean | undefined;
            hash?: string | undefined;
        }, {
            pinned?: boolean | undefined;
            hash?: string | undefined;
        }>>>>;
    }>;
};

export { presets };
